@@ -1,16 +1,25 @@
 #!/usr/bin/env python
+#
+# Copyright 2020 Mark Duffield
+#
+# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
+# except in compliance with the License. A copy of the License is located at
+#
+#     http://aws.amazon.com/apache2.0/
+#
+# or in the "license" file accompanying this file. This file is distributed on an "AS IS"
+# BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations under the License.
+#
 
-
-import os
 import sys
 import csv
 import time
-import argparse
 import subprocess
 from datetime import datetime
 import matplotlib.pyplot as plt
+from matplotlib import dates as mdates
 
-progname = 'pingmon'
 
 def get_date_time(dayonly=False):
 
@@ -54,7 +63,7 @@ def get_ping_data(count, host):
     return cmd_o.decode().split('\n'), terse_info
 
 
-def build_graph(csv_file, title, cr_file=True):
+def build_graph(csv_file, title, cr_file=True, full_day_graph=True):
 
     x = []
     y = []
@@ -68,10 +77,17 @@ def build_graph(csv_file, title, cr_file=True):
             x.append(row[0])
             y.append(float(row[1]))
     plt.figure(figsize=(20, 10), dpi=150)
+
+    if full_day_graph:
+        date_min = x[0].replace(hour=00, minute=00, second=00)
+        date_max = x[-1].replace(hour=23, minute=59, second=59)
+        plt.xlim(date_min, date_max)
     plt.plot_date(x, y, label='Ping results', linestyle='None', marker='.', linewidth=1, markersize=3)
     plt.xlabel('Day of month and Time of day (MM HH:MM)')
     plt.ylabel('Ping time (latency)')
     plt.title(title)
+    date_format = mdates.DateFormatter('%d %H:%M')
+    plt.gca().xaxis.set_major_formatter(date_format)
     plt.legend()
     plt.xticks(fontsize=8)
     plt.yticks(fontsize=8)
@@ -89,8 +105,8 @@ def main():
     plt.ylabel('Time of day')
 
     day_today = get_date_time(dayonly=True)
-    csv_file = open('ping.results.csv.{0}'.format(day_today), 'a')
-    raw_file = open('ping.results.raw.{0}'.format(day_today), 'a')
+    csv_file = open('ping.results.csv.{0}'.format(day_today), 'a', 1)
+    raw_file = open('ping.results.raw.{0}'.format(day_today), 'a', 1)
 
     try:
         while True:
@@ -101,11 +117,13 @@ def main():
                 day_yesterday = day_today
                 day_today = day_now
                 csv_file.close()
-                csv_file = open('ping.results.csv.{0}'.format(day_today), 'a')
+                csv_file = open('ping.results.csv.{0}'.format(day_today), 'a', 1)
                 raw_file.close()
-                raw_file = open('ping.results.raw.{0}'.format(day_today), 'a')
+                raw_file = open('ping.results.raw.{0}'.format(day_today), 'a', 1)
                 build_graph('ping.results.csv.{0}'.format(day_yesterday),
-                            'Ping results for date: {0}'.format(day_yesterday))
+                            'Ping results for date: {0}'.format(day_yesterday),
+                            cr_file=True,
+                            full_day_graph=True)
             runtime = get_date_time()
             ping_data_all,ping_data_t = get_ping_data('1', host)
             print('{0}: {1}'.format(runtime, ping_data_t))
